====================================
RIFT pipeline examples: command-line
====================================

Ini files are not always well-suited for large-scale analyses, particularly of synthetic events with consistent
settings.  The command
